@@ -32,7 +32,7 @@
 #include <QKeyEvent>
 #include <QPainter>
 #include <KLocale>
-#include <KDebug>
+#include <QDebug>
 
 RigidBodyGraphicsItem::RigidBodyGraphicsItem(StepCore::Item* item, WorldModel* worldModel)
     : StepGraphicsItem(item, worldModel)
@@ -65,18 +65,29 @@ QPainterPath RigidBodyGraphicsItem::shape() const
     return _painterPath;
 }
 
-void RigidBodyGraphicsItem::paint(QPainter* painter, const QStyleOptionGraphicsItem* /*option*/, QWidget* /*widget*/)
+void RigidBodyGraphicsItem::paint(QPainter* painter, const QStyleOptionGraphicsItem* /*option*/,
+				  QWidget* /*widget*/)
 {
     //int renderHints = painter->renderHints();
     painter->setRenderHint(QPainter::Antialiasing, true);
 
     QColor color = QColor::fromRgba(rigidBody()->color());
-    if(isItemHighlighted()) color = highlightColor(color);
+    if (isItemHighlighted()) {
+	color = highlightColor(color);
+    }
     painter->setPen(Qt::NoPen);
     painter->setBrush(QBrush(color));
 
     painter->drawPath(_painterPath);
 
+    if (!_markPath.isEmpty()) {
+	QPen pen(color);
+	pen.setWidth(0);
+	painter->setPen(pen);
+	painter->setBrush(QColor(Qt::white));
+        painter->drawPath(_markPath);
+    }
+
     if(_isSelected) {
         double s = currentViewScale();
         QRectF rect = _painterPath.boundingRect();
@@ -235,15 +246,24 @@ void DiskGraphicsItem::viewScaleChanged()
     _painterPath = QPainterPath();
     _painterPath.setFillRule(Qt::WindingFill);
 
+    _markPath = QPainterPath();
+    _painterPath.setFillRule(Qt::WindingFill);
+
     double s = currentViewScale();
     double radius = disk()->radius();
-    if(radius > 1/s) {
+    if (radius > 1/s) {
         _painterPath.addEllipse(-radius, -radius, 2*radius, 2*radius);
-        //_painterPath = QMatrix().rotate(disk()->angle() * 180 / StepCore::Constants::Pi).map(_painterPath);
+
+        _markPath.moveTo(0, 0);
+        _markPath.arcTo(QRectF(-radius, -radius, 2 * radius, 2 * radius),
+                        -15.0, 30.0);
+	_markPath.closeSubpath();
     } else {
         _painterPath.addEllipse(-1/s, -1/s, 2/s, 2/s);
+	// Don't need a marker when the disk is too small to see in detail.
     }
 
+    _markPath = QMatrix().rotate(disk()->angle() * 180 / StepCore::Constants::Pi).map(_markPath);
     RigidBodyGraphicsItem::viewScaleChanged();
 }
 
@@ -467,7 +487,7 @@ bool PolygonCreator::sceneEvent(QEvent* event)
             showMessage(MessageFrame::Information,
                 i18n("Click on the scene to add new vertex or press Enter to finish"));
         }
-        
+
         //fixCenterOfMass();
         //fixInertia();
         return true;
